@@ -6,6 +6,7 @@
 #define LIBWFUT_PLATFORM_H 1
 
 #include <string>
+#include <list>
 
 namespace WFUT {
 
@@ -15,6 +16,7 @@ void os_free_tmpfile(FILE *fp);
 int os_mkdir(const std::string &dir);
 bool os_exists(const std::string &file);
 int os_set_executable(const std::string &file);
+int os_dir_walk(const std::string &path, const std::list<std::string> &excludes, std::list<std::string> &files);
 
 } /* namespace WFUT */
 
